<?php
/**
 * @package   WP Video Contest
 * @author    Socialleadchiefteam
 * @link      http://www.socialleadchief.com/
 */

function remove_menus(){
  
  remove_menu_page( 'edit.php?post_type=wp_video_contest' );     
}
add_action( 'admin_menu', 'remove_menus' );

class Video_Competition_Admin {
	
	

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Slug of the plugin screen.
	 *
	 * @since    1.0.0
	 *
	 * @var      string
	 */
	protected $plugin_screen_hook_suffix = null;

	/**
	 * Initialize the plugin by loading admin scripts & styles and adding a
	 * settings page and menu.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		/**
		 * Call $plugin_slug from public plugin class.
		 */
		$plugin = Video_Competition::get_instance();
		$this->plugin_slug = $plugin->get_plugin_slug();

		// Load admin style sheet and JavaScript.
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_styles' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );

		// Add the options page and menu item.
		add_action( 'admin_menu', array( $this, 'add_plugin_admin_menu' ) );

		// Add an action link pointing to the options page.
		$plugin_basename = plugin_basename( plugin_dir_path( __FILE__ ) . $this->plugin_slug . '.php' );
		add_filter( 'plugin_action_links_' . $plugin_basename, array( $this, 'add_action_links' ) );

		/*
		 * Define custom functionality.
		 */
		add_action('admin_init', array( $this, 'wp_video_contest_output_buffer' ) );
		add_action('wp_ajax_active_video', array( $this, 'wp_video_contest_active_status' ) );
    add_action('wp_ajax_inactive_video', array( $this, 'wp_video_contest_inactive_status' ) );
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Register and enqueue admin-specific style sheet.
	 * 
	 * @since     1.0.0
	 *
	 * @return    null    Return early if no settings page is registered.
	 */
	public function enqueue_admin_styles() {

			wp_enqueue_style( $this->plugin_slug .'-admin-styles', plugins_url( 'css/admin.css', __FILE__ ), array(), Video_Competition::VERSION );
		  wp_enqueue_style('jquery-style', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.2/themes/smoothness/jquery-ui.css');
	}

	/**
	 * Register and enqueue admin-specific JavaScript.
	 * 
	 * @since     1.0.0
	 *
	 * @return    null    Return early if no settings page is registered.
	 */
	public function enqueue_admin_scripts() {

			wp_enqueue_script( $this->plugin_slug . '-admin-script', plugins_url( 'js/admin.js', __FILE__ ), array( 'jquery' ), Video_Competition::VERSION );
      
      wp_enqueue_script( 'jquery-ui-datepicker', plugins_url( 'js/jquery.ui.datepicker.min.js', __FILE__ ), array('jquery-ui-core') , Video_Competition::VERSION, TRUE );
      
    
	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */
	public function add_plugin_admin_menu() {

		add_menu_page(
			__( 'WP Video Contest - Settings', $this->plugin_slug ),
			__( 'WP Video Contest', $this->plugin_slug ),
			'manage_options',
			$this->plugin_slug,
			array( $this, 'display_plugin_admin_page' ),'../wp-content/plugins/wp-video-contest/images/social.png'
		);
    
    add_submenu_page( 
      $this->plugin_slug, 
      __( 'WP Video Contest - Videos', $this->plugin_slug ), 
      __( 'Videos', $this->plugin_slug ), 
      'manage_options', 
      $this->plugin_slug.'-videos', 
      array( $this, 'display_plugin_videos_page' ) 
    );
    add_submenu_page( 
      $this->plugin_slug, 
      __( 'WP Video Contest - Rules & Prizes', $this->plugin_slug ), 
      __( 'Rules & Prizes', $this->plugin_slug ), 
      'manage_options', 
      $this->plugin_slug.'-conditions', 
      array( $this, 'display_plugin_conditions_page' ) 
    );
    add_submenu_page( 
      $this->plugin_slug, 
      __( 'WP Video Contest - Info & Help', $this->plugin_slug ), 
      __( 'Info & Help', $this->plugin_slug ), 
      'manage_options', 
      $this->plugin_slug.'-info', 
      array( $this, 'display_plugin_info_page' ) 
    );
    

	}

	/**
	 * Render the overview page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_admin_page() {
		include_once( 'views/admin.php' );
	}
  /**
	 * Render the configuration page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_configuration_page() {
		include_once( 'views/configuration.php' );
	}
  /**
	 * Render the videos page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_videos_page() {
		include_once( 'views/videos.php' );
	}
  /**
	 * Render the conditions page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_conditions_page() {
		include_once( 'views/conditions.php' );
	}
  /**
	 * Render the info page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_info_page() {
		include_once( 'views/info.php' );
	}

	/**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 */
	public function add_action_links( $links ) {
    //Upravit na správnou url
		return array_merge(
			array(
				'settings' => '<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_slug ) . '">' . __( 'Settings', $this->plugin_slug ) . '</a>'
			),
			$links
		);

	}

  /**
	 * Headers allready sent fix  
	 */
	public function wp_video_contest_output_buffer() {
    ob_start();
  } 



  /**
	 * AJAX change active status  
	 */
public function wp_video_contest_active_status() {
global $wpdb;
  $postid = $_POST['video_id'] ;
  update_post_meta($postid,'contest-active',1);
}

public function wp_video_contest_inactive_status() {
global $wpdb;
  $postid = $_POST['video_id'] ;
  update_post_meta($postid,'contest-active',0);
}

	

}
