<?php
/**
 * @package   WP Video Contest
 * @author    Socialleadchiefteam
 * @link      http://www.socialleadchief.com/
 */

class Video_Competition {

	/**
	 * Plugin version, used for cache-busting of style and script file references.
	 *
	 * @since   1.0.0
	 *
	 * @var     string
	 */
	const VERSION = '1.0.0';

	/**
	 * The variable name is used as the text domain when internationalizing strings
	 * of text. Its value should match the Text Domain file header in the main
	 * plugin file.
	 *
	 * @since    1.0.0
	 *
	 * @var      string
	 */
	protected $plugin_slug = 'wp-video-contest';

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Initialize the plugin by setting localization and loading public scripts
	 * and styles.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		// Load plugin text domain
		add_action( 'init', array( $this, 'load_plugin_textdomain' ) );

		// Activate plugin when new blog is added
		add_action( 'wpmu_new_blog', array( $this, 'activate_new_site' ) );

		// Load public-facing style sheet and JavaScript.
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_styles' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

		/* Define custom functionality.
		 * Refer To http://codex.wordpress.org/Plugin_API#Hooks.2C_Actions_and_Filters
		 */
    //add_action( 'init', array( $this, 'plugin_shortcodes' ) );
    
    add_action('init', array( $this, 'wp_video_contest_front_output_buffer' ) );
    add_action('wp_head', array( $this, 'wp_video_contest_ajaxurl' ) );
    add_action('wp_ajax_vote_for_video', array( $this, 'video_vote_update' ) );
    add_action('wp_ajax_nopriv_vote_for_video',  array( $this, 'video_vote_update' ) );
    add_action( 'init', array( $this, 'video_thumbnail_sizes' ) );
    
    //add_filter('query_vars', array($this, 'contest_parameter_queryvars') );
    
	}                      //vote_for_video

	/**
	 * Return the plugin slug.
	 *
	 * @since    1.0.0
	 *
	 *@return    Plugin slug variable.
	 */
	public function get_plugin_slug() {
		return $this->plugin_slug;
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Fired when the plugin is activated.
	 *
	 * @since    1.0.0
	 *
	 * @param    boolean    $network_wide    True if WPMU superadmin uses
	 *                                       "Network Activate" action, false if
	 *                                       WPMU is disabled or plugin is
	 *                                       activated on an individual blog.
	 */
	public static function activate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide  ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_activate();
				}

				restore_current_blog();

			} else {
				self::single_activate();
			}

		} else {
			self::single_activate();
		}

	}

	/**
	 * Fired when the plugin is deactivated.
	 *
	 * @since    1.0.0
	 *
	 * @param    boolean    $network_wide    True if WPMU superadmin uses
	 *                                       "Network Deactivate" action, false if
	 *                                       WPMU is disabled or plugin is
	 *                                       deactivated on an individual blog.
	 */
	public static function deactivate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_deactivate();

				}

				restore_current_blog();

			} else {
				self::single_deactivate();
			}

		} else {
			self::single_deactivate();
		}

	}

	/**
	 * Fired when a new site is activated with a WPMU environment.
	 *
	 * @since    1.0.0
	 *
	 * @param    int    $blog_id    ID of the new blog.
	 */
	public function activate_new_site( $blog_id ) {

		if ( 1 !== did_action( 'wpmu_new_blog' ) ) {
			return;
		}

		switch_to_blog( $blog_id );
		self::single_activate();
		restore_current_blog();

	}

	/**
	 * Get all blog ids of blogs in the current network that are:
	 * - not archived
	 * - not spam
	 * - not deleted
	 *
	 * @since    1.0.0
	 *
	 * @return   array|false    The blog ids, false if no matches.
	 */
	private static function get_blog_ids() {

		global $wpdb;

		// get an array of blog ids
		$sql = "SELECT blog_id FROM $wpdb->blogs
			WHERE archived = '0' AND spam = '0'
			AND deleted = '0'";

		return $wpdb->get_col( $sql );

	}

	/**
	 * Fired for each blog when the plugin is activated.
	 *
	 * @since    1.0.0
	 */
	private static function single_activate() {
/*		
    //Upload video page
$post_information = array(
    'post_name' => __('upload-video','wp-video-contest'),
    'post_title' => __('Upload video','wp-video-contest'),
    'post_content' => '[contest-menu][contest-upload-video]',
    'post_type' => 'page',
    'post_status' => 'publish'
);
wp_insert_post( $post_information);
    //Gallery page
$post_information = array(
    'post_name' => __('pc-gallery','wp-video-contest'),
    'post_title' => __('video Competition Gallery','wp-video-contest'),
    'post_content' => '[contest-menu][contest-gallery]',
    'post_type' => 'page',
    'post_status' => 'publish'
);
wp_insert_post( $post_information);
    //Page condition
$post_information = array(
    'post_name' => __('contest-condition','wp-video-contest'),
    'post_title' => __('Competition condition','wp-video-contest'),
    'post_content' => '[contest-menu][contest-condition]',
    'post_type' => 'page',
    'post_status' => 'publish'
);
wp_insert_post( $post_information);   

$post_information = array(
    'post_name' => __('video-detail','wp-video-contest'),
    'post_title' => __('video detail','wp-video-contest'),
    'post_content' => '[contest-menu][video-detail]',
    'post_type' => 'page',
    'post_status' => 'publish'
);
wp_insert_post( $post_information);    
*/    
  }

	/**
	 * Fired for each blog when the plugin is deactivated.
	 *
	 * @since    1.0.0
	 */
	private static function single_deactivate() {
		// TODO: Define deactivation functionality here
	}

	/**
	 * Load the plugin text domain for translation.
	 *
	 * @since    1.0.0
	 */
	public function load_plugin_textdomain() {

		$domain = $this->plugin_slug;
		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

		load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' );
		load_plugin_textdomain( $domain, FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );

	}

	/**
	 * Register and enqueue public-facing style sheet.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_slug . '-plugin-styles', plugins_url( 'css/public.css', __FILE__ ), array(), self::VERSION );
		wp_enqueue_style( $this->plugin_slug . '-plugin-styles-2', esc_url_raw( 'http://maxcdn.bootstrapcdn.com/font-awesome/4.1.0/css/font-awesome.min.css', __FILE__ ), array(), self::VERSION );
		wp_enqueue_style( $this->plugin_slug . '-plugin-styles-3', plugins_url( 'css/hover.css', __FILE__ ), array(), self::VERSION );
	}
		

	/**
	 * Register and enqueues public-facing JavaScript files.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( $this->plugin_slug . '-plugin-script', plugins_url( 'js/public.js', __FILE__ ), array( 'jquery' ), self::VERSION );
	}

  /**
	 * Include shortcodes
	 *   
	 * @since    1.0.0
	 */
	public function plugin_shortcodes() {
  
    include('shortcodes/shortcodes.php');
  
  }
  
  /**
	 * Headers allready sent fix  
	 */
	public function wp_video_contest_front_output_buffer() {
    ob_start();
  } 

	
  public function video_thumbnail_sizes()
	{
    add_theme_support('post-thumbnails');
    add_image_size('gallery-big', 400, 400, true);
    add_image_size('gallery-middle', 350, 350, true);
    add_image_size('gallery-small', 200, 200, true);
    add_image_size('video-small', 51, 51, true);
  }
  
  public function video_vote_update(){
  
    $postid = $_POST['video_id'] ;
    $points = get_post_meta($postid,'contest-video-points',true);
    $points = $points+1;
    update_post_meta($postid,'contest-video-points',$points);
  
    $ips = get_post_meta($postid,'contest-video-ip',true);
    $ip_address=explode(',',$ips);
    if(empty($ips)){
    $ips = $_SERVER['REMOTE_ADDR'].',';
    update_post_meta($postid,'contest-video-ip',$ips);
    }else{
    if(!in_array($_SERVER['REMOTE_ADDR'],$ip_address)){
    $ips = $ips.$_SERVER['REMOTE_ADDR'].',';
    update_post_meta($postid,'contest-video-ip',$ips);
    }
    }
    
    
     if(is_user_logged_in()){
      
      $user_ID = get_current_user_id();
      
      $users_ids = get_post_meta($postid,'contest-video-users',true);
      $ids_array = explode(',',$users_ids);
      
      if(empty($ids)){
        
        $ids = $user_ID.',';
        update_post_meta($postid,'contest-video-users',$ids);
        
      }else{
          if(!in_array($user_ID,$ids_array)){
              
              $ids = $users_ids.$user_ID.',';
              update_post_meta($postid,'contest-video-users',$ids);
          }
      }
    }
    
    exit();
  }
  
  public function wp_video_contest_ajaxurl(){
    ?>
      <script type="text/javascript">
        var ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>';
      </script>
    <?php
  }
  
  
  
public function contest_parameter_queryvars( $qvars )
  {
    //$qvars[] = ' contest';
    //return $qvars;
  }

}
?>